// @ts-nocheck
import "./element-highlight.css";

import React, { useEffect, useState } from "react";
import mouseEvents from "./mouse-events";

const useCapture = true;
const activeClassName = "contenteditable-element-selector-active";

const ElementHighlight = ({
  applicationRootElement,
  isActiveRef,
  onSelect,
  children,
}) => {
  useEffect(() => {
    const mouseOutCallback = (event) => {
      const target: HTMLElement = event.target;
      if (!applicationRootElement.contains(target)) return;
      target.classList.remove("contenteditable-element-hover");
    };

    const mouseOverCallback = (event) => {
      const target: HTMLElement = event.target;
      if (!isActiveRef || !isActiveRef.current) return;
      if (!applicationRootElement.contains(target)) return;
      target.classList.add("contenteditable-element-hover");
    };

    const mouseClickCallback = (event) => {
      const target: HTMLElement = event.target;
      if (!isActiveRef || !isActiveRef.current) return;
      if (!applicationRootElement.contains(target)) return;
      event.preventDefault();
      event.stopPropagation();
      const selected = document.querySelector(
        ".contenteditable-element-seleted"
      );
      if (selected)
        selected.classList.remove("contenteditable-element-seleted");
      target.classList.add("contenteditable-element-seleted");
      onSelect(target);
    };

    window.addEventListener("mouseout", mouseOutCallback, useCapture);
    window.addEventListener("mouseover", mouseOverCallback, useCapture);
    window.addEventListener("click", mouseClickCallback, useCapture);

    return () => {
      window.removeEventListener("mouseout", mouseOutCallback, useCapture);
      window.removeEventListener("mouseover", mouseOverCallback, useCapture);
      window.removeEventListener("click", mouseClickCallback, useCapture);
    };
  }, []);

  useEffect(() => {
    if (isActiveRef && isActiveRef.current) {
      const propKey = isActiveRef.current ? "add" : "remove";
      window.document.body.classList[propKey](activeClassName);
    }
    return () => {
      window.document.body.classList.remove(activeClassName);
    };
  }, [isActiveRef && isActiveRef.current]);
  return children ? <>{children}</> : null;
};

export default ElementHighlight;
